@@ -39,7 +39,8 @@ class Ingo_LoginTasks_SystemTask_Upgrade extends Horde_Core_LoginTasks_SystemTas
         case '2.0':
             /* Upgrade to the new preferences storage format. */
             $upgrade_prefs = array(
-                'rules'
+                'rules',
+                'vacation',
             );
 
             $GLOBALS['injector']->getInstance('Horde_Core_Prefs_Storage_Upgrade')->upgradeSerialized($GLOBALS['prefs'], $upgrade_prefs);
