@@ -180,7 +180,7 @@ DATE=`date +%s`
 DUMMY=`test -f ${VACATION_DIR:-.}/\'.vacation.from@example.com\' && test $FILEDATE -le $DATE && rm ${VACATION_DIR:-.}/\'.vacation.from@example.com\'`
 :0 h
 SUBJECT=| formail -xSubject:
-:0 Whc: ${VACATION_DIR:-.}/vacation.lock
+:0 Wc: ${VACATION_DIR:-.}/vacation.lock
 {
 :0 Wh
 * ^TO_from@example.com
